<center><img src='https://github.com/Airscker/Purple-Micro-Star/blob/Web/imgs/PMS.png?raw=true'></center>

# MultiBody Celestial Motion Simulation

## Introduction

This is a package built for simulating Multibody Celestial motion and Gravitational Wave of Pulsars or Binary Celestial Bodies.

To install this package just using `pip`:
```sh
pip install PurpleMicroStar
```
And the document is available here at [Home Page of Purple Micro Star](https://airscker.github.io/Purple-Micro-Star/)

## Available Operation
- **MultiGravity Simulation**:
	Simulating motion curve of a cluster of celestial bodies, from single celestial body to as many as possible. Let's see the motion curve of 215 celestial bodies in 10s:

<center><img src='https://github.com/Airscker/Purple-Micro-Star/blob/Web/imgs/215_0.01_1e3.png?raw=true'></center>

Or Let's see 6 celestial bodies in 1e6s:

<center><img src='https://github.com/Airscker/Purple-Micro-Star/blob/Web/imgs/6_10_1e5.png?raw=true'></center>

- **Single Celestial Simulation**:
	Building single celestial body and give out its properties, including Roche Limit and others
- **Gravitational Wave Simulation**
	Simulating Gravitational Wave signal of binary celestial bodies or pulsars, less to say and look at some beautiful results:

1. Gravitational Wave Field Distribution of Binary Celestial Bodies:
<center><img src='https://github.com/Airscker/Purple-Micro-Star/blob/Web/imgs/gw1.png?raw=true'></center>
<center><img src='https://github.com/Airscker/Purple-Micro-Star/blob/Web/imgs/gw2.png?raw=true'></center>
2. Gravitational Wave Evolution via Time
<center><img src='https://github.com/Airscker/Purple-Micro-Star/blob/Web/imgs/CBIG.jpg?raw=true'></center>
3. Pulsar Continuous Gravitational Wave
<center><img src='https://github.com/Airscker/Purple-Micro-Star/blob/Web/imgs/pulsar.png?raw=true'></center>


## Key Information
- Author: Airscker/Yufeng Wang
- License: GPL-3.0 License
- Date: 2022-6

## Key Folders
- CBIG_DATA: Compact Binary Inspiral Celestial Bodies' Gravitational Wave Data Images Generated by Project
- Curve_data: MultiBody Motion Curve Data generated by Project
- exampledata: MultiBoby Basic Properties. Saved as .csv file
- PurpleMicroStar: Containing All Open Source Code files